@@ -111,8 +111,9 @@ void MainWindow::onGroupButton(int button_id)
     if (dialog.exec() != QDialog::Accepted || dialog.selection().isEmpty()) {
         return;
     }
-    auto selectedButton = buttonGroup->button(button_id);
-    selectedButton->setText(dialog.selection());
+
+    QString selectedLocale = dialog.selection();
+
     static const QHash<int, QString> hashVarName {
         {ButtonID::Lang, "LANG"},
         {ButtonID::Address, "LC_ADDRESS"},
@@ -128,12 +129,35 @@ void MainWindow::onGroupButton(int button_id)
         {ButtonID::Telephone, "LC_TELEPHONE"},
         {ButtonID::Time, "LC_TIME"},
     };
-    if (button_id == ButtonID::Lang) {
-        setSubvariables();
+
+    if (button_id == ButtonID::All) {
+        // Set all categories except Lang to the selected locale
+        Cmd cmd;
+        for (auto it = hashVarName.constBegin(); it != hashVarName.constEnd(); ++it) {
+            int categoryId = it.key();
+            if (categoryId == ButtonID::Lang) {
+                continue;
+            }
+
+            auto button = buttonGroup->button(categoryId);
+            if (button) {
+                button->setText(selectedLocale);
+                const QString updateLocaleCommand = QString("update-locale %1='%2'").arg(it.value(), selectedLocale);
+                cmd.runAsRoot(updateLocaleCommand);
+            }
+        }
+    } else {
+        // Handle individual button case
+        auto selectedButton = buttonGroup->button(button_id);
+        selectedButton->setText(selectedLocale);
+        if (button_id == ButtonID::Lang) {
+            setSubvariables();
+        }
+        const QString updateLocaleCommand
+            = QString("update-locale %1='%2'").arg(hashVarName.value(button_id), selectedLocale);
+        Cmd().runAsRoot(updateLocaleCommand);
     }
-    const QString updateLocaleCommand
-        = QString("update-locale %1='%2'").arg(hashVarName.value(button_id), selectedButton->text());
-    Cmd().runAsRoot(updateLocaleCommand);
+
     ui->pushResetSubvar->setVisible(anyDifferentSubvars());
 }
 
@@ -158,14 +182,14 @@ void MainWindow::aboutClicked()
                              "href=\"http://mxlinux.org\">http://mxlinux.org</a><br "
                              "/></p><p align=\"center\">"
                            + tr("Copyright (c) MX Linux") + "<br /><br /></p>",
-                       "/usr/share/doc/mx-locale/license.html", tr("%1 License").arg(this->windowTitle()), true);
+                       "/usr/share/doc/mx-locale/license.html", tr("%1 License").arg(this->windowTitle()));
     this->show();
 }
 
 void MainWindow::helpClicked()
 {
     QString url = "file:///usr/share/doc/mx-locale/help/mx-locale.html";
-    displayDoc(url, tr("%1 Help").arg(this->windowTitle()), true);
+    displayDoc(url, tr("%1 Help").arg(this->windowTitle()));
 }
 
 QString MainWindow::getCurrentLang() const
@@ -239,6 +263,7 @@ void MainWindow::setButtons()
     buttonGroup->addButton(ui->pushButtonTelephone, ButtonID::Telephone);
     buttonGroup->addButton(ui->pushButtonTime, ButtonID::Time);
     buttonGroup->addButton(ui->buttonLang, ButtonID::Lang);
+    buttonGroup->addButton(ui->pushButtonAll, ButtonID::All);
 }
 
 void MainWindow::setConnections()
